@@ -2,7 +2,7 @@
 #define	ARM_CPU_TYPES_H
 
 /*
- *  Copyright (C) 2005-2009  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2010  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -41,7 +41,7 @@
 #define	ARM_DUAL_ENDIAN		2
 #define	ARM_XSCALE		4
 
-#include "armreg.h"
+#include "thirdparty/armreg.h"
 
 /*
  *  NOTE: Most of these are bogus!
