@@ -2,7 +2,7 @@
 #define	CPU_H
 
 /*
- *  Copyright (C) 2005-2009  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2010  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -229,14 +229,11 @@ struct physpage_ranges {
 
 
 /*  Include all CPUs' header files here:  */
-#include "cpu_alpha.h"
 #include "cpu_arm.h"
-#include "cpu_m32r.h"
 #include "cpu_m88k.h"
 #include "cpu_mips.h"
 #include "cpu_ppc.h"
 #include "cpu_sh.h"
-#include "cpu_sparc.h"
 
 struct cpu;
 struct emul;
@@ -439,14 +436,11 @@ struct cpu {
 	 *  specifics, etc.
 	 */
 	union {
-		struct alpha_cpu      alpha;
 		struct arm_cpu        arm;
-		struct m32r_cpu       m32r;
 		struct m88k_cpu       m88k;
 		struct mips_cpu       mips;
 		struct ppc_cpu        ppc;
 		struct sh_cpu         sh;
-		struct sparc_cpu      sparc;
 	} cd;
 };
 
@@ -505,7 +499,7 @@ void cpu_init(void);
 #define CPU_FAMILY_INIT(n,s)	int n ## _cpu_family_init(		\
 	struct cpu_family *fp) {					\
 	/*  Fill in the cpu_family struct with valid data for this arch.  */ \
-	fp->name = s;							\
+	fp->name = strdup(s);						\
 	fp->cpu_new = n ## _cpu_new;					\
 	fp->list_available_types = n ## _cpu_list_available_types;	\
 	fp->disassemble_instr = n ## _cpu_disassemble_instr;		\
