@@ -2,7 +2,7 @@
 #define	CPU_ARM_H
 
 /*
- *  Copyright (C) 2005-2009  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2010  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -38,7 +38,7 @@ struct cpu_family;
 
 /*  ARM CPU types:  */
 struct arm_cpu_type_def {
-	char		*name;
+	const char	*name;
 	uint32_t	cpu_id;
 	int		flags;
 	int		icache_shift;
