@@ -2,7 +2,7 @@
 #define	CPU_PPC_H
 
 /*
- *  Copyright (C) 2005-2009  Anders Gavare.  All rights reserved.
+ *  Copyright (C) 2005-2010  Anders Gavare.  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions are met:
@@ -41,7 +41,7 @@ struct cpu_family;
 
 /*  PPC CPU types:  */
 struct ppc_cpu_type_def { 
-	char		*name;
+	const char	*name;
 	int		pvr;
 	int		bits;
 	int		flags;
